{{/*
Expand the name of the chart.
*/}}
{{- define "commento.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "commento.fullname" -}}
{{- if .Values.fullnameOverride }}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- $name := default .Chart.Name .Values.nameOverride }}
{{- if contains $name .Release.Name }}
{{- .Release.Name | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" }}
{{- end }}
{{- end }}
{{- end }}

{{- define "postgres.servicename" -}}
{{- if .Values.postgres.fullnameOverride }}
{{- .Values.postgres.fullnameOverride | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- $name := default "postgres" .Values.postgres.nameOverride }}
{{- if contains $name .Release.Name }}
{{- .Release.Name | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" }}
{{- end }}
{{- end }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "commento.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "commento.labels" -}}
helm.sh/chart: {{ include "commento.chart" . }}
{{ include "commento.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "commento.selectorLabels" -}}
app.kubernetes.io/name: {{ include "commento.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end }}

{{/*
Create the name of the service account to use
*/}}
{{- define "commento.serviceAccountName" -}}
{{- if .Values.serviceAccount.create }}
{{- default (include "commento.fullname" .) .Values.serviceAccount.name }}
{{- else }}
{{- default "default" .Values.serviceAccount.name }}
{{- end }}
{{- end }}

{{/*
Commento settings via environment variables
*/}}
{{- define "commento.environment" -}}
- name: COMMENTO_FORBID_NEW_OWNERS
  value: {{ .Values.settings.forbidNewOwners | quote }}
- name: COMMENTO_GZIP_STATIC
  value: {{ .Values.settings.gzipStaticContent | quote }}
- name: COMMENTO_PORT
  value: {{ .Values.containerPort | quote }}
{{- if .Values.settings.origin }}
- name: COMMENTO_ORIGIN
  value: {{ .Values.settings.origin | quote }}
{{- else }}
{{- if .Values.ingress.enabled }}
- name: COMMENTO_ORIGIN
  value: {{ (printf "%s://%s" .Values.settings.protocol .Values.ingress.host) | quote }}
{{- end }}
{{- end }}
{{- with .Values.settings.smtp }}
  {{- if .enabled }}
- name: COMMENTO_SMTP_HOST
  value: {{ .host | quote }}
- name: COMMENTO_SMTP_PORT
  value: {{ .port | quote }}
- name: COMMENTO_SMTP_FROM_ADDRESS
  value: {{ .from | quote }}
  {{- end }}
{{- end }}
{{- end }}
